from typing import Final, Sequence

__author__: Final[str] = "owtotwo"
__copyright__: Final[str] = "Copyright 2020 owtotwo"
__credits__: Final[Sequence[str]] = ["owtotwo"]
__license__: Final[str] = "LGPLv3"
__version__: Final[str] = "0.0.1"
__maintainer__: Final[str] = "owtotwo"
__email__: Final[str] = "owtotwo@163.com"
__status__: Final[str] = "Experimental"
